pub struct Grouping {
pub key: Option<String>,
pub function: Option<String>,
}Expand description
How the viewer should cluster nodes in the diagram. Exactly one of key
(group by the value of a node attribute, e.g. crate) or function (a named
grouper the viewer implements, e.g. dir — derive the folder from the path).
Absent → the viewer falls back to its default dir grouper.
Fields
key: Option<String>function: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Grouping
impl<'de> Deserialize<'de> for Grouping
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more