pub fn report_override(cfg: &Table) -> ReportOverrideExpand description
Read the [report] section of a merged config table as a ReportOverride
(used for a language’s <lang>.toml, which nests it under report).
pub fn report_override(cfg: &Table) -> ReportOverrideRead the [report] section of a merged config table as a ReportOverride
(used for a language’s <lang>.toml, which nests it under report).